Blob class
Constructors
Properties
-
bytes
→ Future<
Uint8List?> -
no setter
-
bytesAsBroadcastStream
→ Stream<
Uint8List?> -
no setter
-
bytesAsStream
→ Stream<
Uint8List?> -
no setter
- bytesSync → Uint8List?
-
no setter
- chunks → Uint8List?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- metadata → Document?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
no setter
- sizeAsHumanReadable → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited