BlobStorage class

Constructors

BlobStorage({required String name, required String path, required int chunksSize, required bool encrypted})

Properties

count Future<int>
no setter
countAsHumanReadable Future<String>
no setter
countAsHumanReadableSync String
no setter
countSync int
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty Future<bool>
no setter
isEmptySync bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Future<int>
no setter
sizeAsHumanReadable Future<String>
no setter
sizeAsHumanReadableSync String
no setter
sizeSync int
no setter

Methods

add({required Uint8List bytes, Map<String, dynamic>? metadata}) Future<void>
addSync({required Uint8List bytes, Map<String, dynamic>? metadata}) → void
clear({bool force = false}) Future<void>
clearSync({bool force = false}) → void
delete({required QueryBuilder query(Collection collection)}) Future<void>
deleteById(String id) Future<void>
deleteSync({required QueryBuilder query(Collection collection)}) → void
deleteSyncById(String id) → void
get({QueryBuilder query(Collection collection)?, int? count}) Future<List<Blob>>
getSync({QueryBuilder query(Collection collection)?, int? count}) List<Blob>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset({bool force = false}) Future<void>
resetSync({bool force = false}) → void
toString() String
A string representation of this object.
override
update({required QueryBuilder query(Collection collection), Map<String, dynamic>? metadata, Uint8List? bytes}) Future<List<Blob>>
updateById(String id, {Map<String, dynamic>? metadata, Uint8List? bytes}) Future<Blob?>
updateSync({required QueryBuilder query(Collection collection), Map<String, dynamic>? metadata, Uint8List? bytes}) List<Blob>
updateSyncById(String id, {Map<String, dynamic>? metadata, Uint8List? bytes}) Blob?

Operators

operator ==(Object other) bool
The equality operator.
inherited