Database class
Constructors
Properties
-
backups
→ List<
Backup> -
no setter
-
blobStorages
→ Map<
String, BlobStorage> -
no setter
-
collections
→ Map<
String, Collection> -
no setter
- encrypted → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isWeb → bool
-
no setter
- name → String
-
final
- path → String
-
no setter
-
relations
→ Map<
String, Relation> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
no setter
- sizeFormatted → String
-
no setter
-
stores
→ Map<
String, Store> -
no setter
Methods
-
backup(
String name) → Backup -
blobStorage(
String name, {int chunksSize = 1024 * 512, bool? encrypt, String? secretKey}) → BlobStorage -
clear(
) → void -
collection(
String name) → Collection -
collectionExists(
String name) → bool -
collectionsList(
{List< String> ? pick, List<String> ? omit}) → List<Collection> -
drop(
) → void -
dropCollection(
String collectionName) → void -
dropStore(
String storeName) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
relation(
String collectionName, String localKey, {required String name}) → Relation -
removeAllBackups(
) → void -
removeBackup(
String name) → void -
reset(
) → void -
store(
String name) → Store -
storeExists(
String name) → bool -
storesList(
{List< String> ? pick, List<String> ? omit}) → List<Store> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited