Store constructor
Implementation
Store({required String name, required String path, bool encrypted = false, bool isWeb = false})
: _name = name,
_storage = StoreFileStorage(path: path, encrypted: encrypted);
Store({required String name, required String path, bool encrypted = false, bool isWeb = false})
: _name = name,
_storage = StoreFileStorage(path: path, encrypted: encrypted);