Env class

Constructors

Env({String? path, String? secretKey})

Properties

all Map<String, dynamic>
no setter
count int
no setter
formatted String
no setter
hashCode int
The hash code for this object.
no setterinherited
keys List<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List
no setter

Methods

contains(String substring) Map<String, dynamic>
endsWith(String suffix) Map<String, dynamic>
has(String key) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
omit(List<String> keys) Map<String, dynamic>
pick(List<String> keys) Map<String, dynamic>
regexMatch(String pattern) Map<String, dynamic>
startsWith(String prefix) Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) → dynamic