Json class

Constructors

Json()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getNested(dynamic input, String path) → dynamic
mapToCSV(List<Map<String, dynamic>> map) String
parse(dynamic value) → dynamic
remove(dynamic input, String path) → dynamic
stringify(Map<String, dynamic> map) String
update(Map? json, String path, dynamic newValue) → dynamic