Performance class

Constructors

Performance({required String name})

Properties

duration Duration
no setter
durationFormatted String
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopwatch Stopwatch
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printIt() → void
start() → void
stop() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

test<T>(String name, FutureOr<T> func()) Future<PerformanceResult<T>>