PrintColor enum
Values
- red → const PrintColor
-
const PrintColor(31) - green → const PrintColor
-
const PrintColor(32) - yellow → const PrintColor
-
const PrintColor(33) - blue → const PrintColor
-
const PrintColor(34) - magenta → const PrintColor
-
const PrintColor(35) - white → const PrintColor
-
const PrintColor(37) - black → const PrintColor
-
const PrintColor(30) - grey → const PrintColor
-
const PrintColor(90) - lightGrey → const PrintColor
-
const PrintColor(97) - lightRed → const PrintColor
-
const PrintColor(91) - lightGreen → const PrintColor
-
const PrintColor(92) - lightYellow → const PrintColor
-
const PrintColor(93) - lightBlue → const PrintColor
-
const PrintColor(94) - lightMagenta → const PrintColor
-
const PrintColor(95) - lightCyan → const PrintColor
-
const PrintColor(96) - lightWhite → const PrintColor
-
const PrintColor(97)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PrintColor> - A constant List of the values in this enum, in order of their declaration.