PrintColored class

Constructors

PrintColored()

Properties

hashCode int
The hash code for this object.
no setterinherited
outputs List<Output>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

black(String text) PrintColored
blackBold(String text) PrintColored
blue(String text) PrintColored
blueBold(String text) PrintColored
chain(String text, [PrintColor? color, bool? isBold]) PrintColored
chainln(String text, [PrintColor? color, bool? isBold]) PrintColored
getIt() String
green(String text) PrintColored
greenBold(String text) PrintColored
magenta(String text) PrintColored
magentaBold(String text) PrintColored
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printit() → void
red(String text) PrintColored
redBold(String text) PrintColored
throwIt() → void
toString() String
A string representation of this object.
inherited
white(String text) PrintColored
whiteBold(String text) PrintColored
yellow(String text) PrintColored
yellowBold(String text) PrintColored

Operators

operator ==(Object other) bool
The equality operator.
inherited