core library

Classes

BGWorker
Collection
Database
Encryptor
Provides simple symmetric encryption and decryption utilities. NOTE: This is NOT a replacement for proper cryptography. For sensitive data, use a package like encrypt or pointycastle, as this logic is not cryptographically secure.
FlowState<T>
Format
Json
Performance
PrintColored
Random
Record
Store

Enums

PrintColor

Functions

openDatabase(String name, {String? path, bool? encrypted, String? secretKey, bool? isWeb = false}) Database