FlowState<T> class
Static Methods
-
combine2<T, A, B>(FlowState<A> one, FlowState<B> two, [T combiner(A a, B b)?])
→ FlowState<T>
-
-
combine3<T, A, B, C>(FlowState<A> one, FlowState<B> two, FlowState<C> three, [T combiner(A a, B b, C c)?])
→ FlowState<T>
-
-
combine4<T, A, B, C, D>(FlowState<A> one, FlowState<B> two, FlowState<C> three, FlowState<D> four, [T combiner(A a, B b, C c, D d)?])
→ FlowState<T>
-
-
combine5<T, A, B, C, D, E>(FlowState<A> one, FlowState<B> two, FlowState<C> three, FlowState<D> four, FlowState<E> five, [T combiner(A a, B b, C c, D d, E e)?])
→ FlowState<T>
-
-
combine6<T, A, B, C, D, E, F>(FlowState<A> one, FlowState<B> two, FlowState<C> three, FlowState<D> four, FlowState<E> five, FlowState<F> six, [T combiner(A a, B b, C c, D d, E e, F f)?])
→ FlowState<T>
-
-
combine7<T, A, B, C, D, E, F, G>(FlowState<A> one, FlowState<B> two, FlowState<C> three, FlowState<D> four, FlowState<E> five, FlowState<F> six, FlowState<G> seven, [T combiner(A a, B b, C c, D d, E e, F f, G g)?])
→ FlowState<T>
-
-
combine8<T, A, B, C, D, E, F, G, H>(FlowState<A> one, FlowState<B> two, FlowState<C> three, FlowState<D> four, FlowState<E> five, FlowState<F> six, FlowState<G> seven, FlowState<H> eight, [T combiner(A a, B b, C c, D d, E e, F f, G g, H h)?])
→ FlowState<T>
-
-
combine9<T, A, B, C, D, E, F, G, H, I>(FlowState<A> one, FlowState<B> two, FlowState<C> three, FlowState<D> four, FlowState<E> five, FlowState<F> six, FlowState<G> seven, FlowState<H> eight, FlowState<I> nine, [T combiner(A a, B b, C c, D d, E e, F f, G g, H h, I i)?])
→ FlowState<T>
-
-
list<T>(List<FlowState<T?>> states)
→ FlowState<List<T?>>
-