Store class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
no setter
- sizeFormatted → String
-
no setter
Methods
-
all(
) → dynamic -
clear(
) → dynamic -
create(
) → void -
drop(
) → void -
get(
String key) → dynamic -
has(
String key) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String key) → dynamic -
set(
String key, dynamic value) → dynamic -
setFrom(
String key, dynamic func(dynamic data), [dynamic fallback]) → dynamic -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited