BGWorker class

Constructors

BGWorker()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

run<I, O>(FutureOr<O> task(I data), [I? data]) Future<O>
Runs task in a separate isolate. data will be passed to the task.