PrintColored class

Constructors

PrintColored()

Properties

hashCode int
The hash code for this object.
no setterinherited
outputs List<Output>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

chain(String text, [PrintColor? color, bool? isBold]) PrintColored
chainln(String text, [PrintColor? color, bool? isBold]) PrintColored
getIt() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printit() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited